@@ -64,7 +64,7 @@ PHPC_OBJ_DEFINE_HANDLER_VAR(gnupg);
 				break; \
 			case 2: \
 				zend_throw_exception(\
-					zend_exception_get_default(TSRMLS_C), \
+					zend_ce_exception, \
 					(char*) error, \
 					0 TSRMLS_CC \
 				); \
@@ -169,7 +169,7 @@ static void php_gnupg_this_make(PHPC_THIS_DECLARE(gnupg), zval *options TSRMLS_D
 			if (gpgme_ctx_set_engine_info(
 					ctx, GPGME_PROTOCOL_OpenPGP, file_name, home_dir) != GPG_ERR_NO_ERROR) {
 				zend_throw_exception(
-					zend_exception_get_default(TSRMLS_C),
+					zend_ce_exception,
 					(char*) "Setting engine info failed",
 					0 TSRMLS_CC
 				);
@@ -341,7 +341,9 @@ phpc_function_entry gnupg_methods[] = {
 	PHP_GNUPG_FALIAS(addencryptkey,     arginfo_gnupg_key_method)
 	PHP_GNUPG_FALIAS(adddecryptkey,     arginfo_gnupg_key_passphrase_method)
 	PHP_GNUPG_FALIAS(deletekey,         arginfo_gnupg_deletekey_method)
+#if GPGME_VERSION_NUMBER < 0x020000  /* GPGME < 2.0.0 */
 	PHP_GNUPG_FALIAS(gettrustlist,      arginfo_gnupg_pattern_method)
+#endif
 	PHP_GNUPG_FALIAS(listsignatures,    arginfo_gnupg_keyid_method)
 	PHP_GNUPG_FALIAS(seterrormode,      arginfo_gnupg_errmode_method)
 	PHPC_FE_END
@@ -483,7 +485,9 @@ static zend_function_entry gnupg_functions[] = {
 	PHP_FE(gnupg_addencryptkey,		arginfo_gnupg_key_function)
 	PHP_FE(gnupg_adddecryptkey,		arginfo_gnupg_key_passphrase_function)
 	PHP_FE(gnupg_deletekey,			arginfo_gnupg_deletekey_function)
+#if GPGME_VERSION_NUMBER < 0x020000  /* GPGME < 2.0.0 */
 	PHP_FE(gnupg_gettrustlist,		arginfo_gnupg_pattern_function)
+#endif
 	PHP_FE(gnupg_listsignatures,	arginfo_gnupg_keyid_function)
 	PHP_FE(gnupg_seterrormode,		arginfo_gnupg_errmode_function)
 	PHPC_FE_END
@@ -1936,6 +1940,8 @@ PHP_FUNCTION(gnupg_deletekey)
 }
 /* }}} */
 
+#if GPGME_VERSION_NUMBER < 0x020000  /* GPGME < 2.0.0 */
+
 /* {{{ proto array gnupg_gettrustlist(string pattern)
 * searching for trust items which match PATTERN
 */
@@ -1981,6 +1987,8 @@ PHP_FUNCTION(gnupg_gettrustlist)
 }
 /* }}} */
 
+#endif /* GPGME < 2.0.0 */
+
 /* {{{ proto array gnupg_listsignatures(string keyid) */
 PHP_FUNCTION(gnupg_listsignatures)
 {
